import {Component, ElementRef, ViewChild} from '@angular/core';
import {NavController, IonicPage, Slides} from 'ionic-angular';
import {ActivityListPage} from "../../home/activity/activityList/activityList";
import {Http, Response} from '@angular/http';
import {AppService, AppGlobal} from '../../../service/http.service';
import {Calendar} from '@ionic-native/calendar';
import {ActivityApplyPage} from "../../home/activity/activityApply/activityApply";
import {ActivityDetailPage} from "../../home/activity/activityDetail/activityDetail";
import {OutGoingReportPage} from "../../home/report/outGoingReport/outGoingReport";
import {AnnouncementPage} from '../../home/announcement/announcementList/announcement';
import {Storage} from '@ionic/storage';
import {OutGoingReportEditPage} from "../../home/report/outGoingReportEdit/outGoingReportEdit";
import {AnnouncementViewPage} from '../../home/announcement/announcementView/announcementView';
import {CalendarComponentOptions, DayConfig} from "ion2-calendar";
import {NoticePage} from "../notice/notice";
import {monthCh, weekDay} from "../../../app/main";
import {Badge} from '@ionic-native/badge';
import {TabsService} from "../tabs.service";
import {TextToSpeech} from "@ionic-native/text-to-speech";
import {CommonService} from "../../../provide/common.service";
import {SearchNewPage} from "../../home-pages/search-new/search-new";
import {StuffDetailPage} from "../../home-pages/stuff-detail/stuff-detail";

declare var Swiper;

@IonicPage()
@Component({
    selector: 'page-home',
    templateUrl: 'home.html'
})

export class HomePage {
    @ViewChild(Slides) slides: Slides;
    @ViewChild('tips') tips: ElementRef;

    picture: string = AppGlobal.picture;
    slidersItems = [];
    noticeList = [];
    tabsList = [{name: "党规党章",}, {name: "系列讲话",}, {name: "中央精神",},{name:"本市部署"}];
    index = 0;
    isSign = false;

    newList = [];


    constructor(public navCtrl: NavController,public tts:TextToSpeech,
                public commonSer:CommonService,
                public appService: AppService, public http: Http, private calendar: Calendar, public storage: Storage,
                public badge: Badge, public tabsSer: TabsService) {

    }


    ionViewDidLoad(){
        this.tabsSer.getBanner().subscribe(
            (res)=>{
                this.slidersItems = res;
            }
        )
        this.change(0);
        this.getBanner();
    }

    //获取轮播图
    getBanner(){
        const data = {
            obj:{
                isRecommend:1,
            }
        }
        this.tabsSer.stuffPage(data).subscribe(
            (res)=>{

            }
        )
    }

    //所属板块类型(1党规党章,2系列讲话,3中央精神,4本市部署,5通知公告,6党建动态,7工作提示,
    //      * 8党务参考,9廉政格言,10纪检提示,11风险排查,12警示教育,13支部活动,14党建联建,15结对帮扶)
    change(index) {
        let itemWidth = window.screen.width / 4;
        // 自身div的一半 - 滑块的一半
        this.tips.nativeElement.style.left = itemWidth * index + itemWidth / 2 - this.tips.nativeElement.offsetWidth / 2 + 'px';
        this.index = index;
        const data = {
            pageSize:1,
            pageCount:100,
            obj:{
                'plateType':index +1
            }
        }
        this.tabsSer.stuffPage(data).subscribe(
            (res)=>{
                this.newList = res.data;
            }
        )
    }

    //签到
    signUp(){
        this.tabsSer.sign().subscribe(
            (res)=>{
                this.isSign = false;
                if(res.errcode == '1000'){
                    this.commonSer.toast('签到成功');
                }else{
                    this.commonSer.toast(res.errmsg);
                }
            }
        )
    }

    //查看文章详情
    goToDetail(item){
        this.navCtrl.push(StuffDetailPage,{
            id:item.id
        })
    }

    //前往搜索页面
    goToSearch(){
        this.navCtrl.push(SearchNewPage);
    }

}
